@@ -147,7 +147,7 @@ subroutine Anomaly_1d( nx, x, anor, error )  ! 1 ǡк֤
      call Mean_1d( nx, x, ave, error )
      do i=1,nx
         if(x(i)==error)then
-           anor(i)=0.0
+           anor(i)=error
         else
            anor(i)=x(i)-ave
         end if
@@ -177,7 +177,7 @@ subroutine Anomaly_2d( nx, ny, x, anor, error )  ! 2 ǡк֤
      do j=1,ny
         do i=1,nx
            if(x(i,j)==error)then
-              anor(i,j)=0.0
+              anor(i,j)=error
            else
               anor(i,j)=x(i,j)-ave
            end if
@@ -212,7 +212,7 @@ subroutine Anomaly_3d( nx, ny, nz, x, anor, error )  ! 3 ǡк֤
         do j=1,ny
            do i=1,nx
               if(x(i,j,k)==error)then
-                 anor(i,j,k)=0.0
+                 anor(i,j,k)=error
               else
                  anor(i,j,k)=x(i,j,k)-ave
               end if
@@ -296,36 +296,54 @@ subroutine covariance( nx, x, y, cov, error )  ! 2 Ĥ 1 ǡζʬ׻
 end subroutine covariance
 
 
-subroutine interpo_search_1d( x, point, i )
+subroutine interpo_search_1d( x, point, i, undeff )
   ! ǿ뤴Ȥͤ礭ʤˤΤʤ,
   ! point ֹϤ.
   implicit none
   real, intent(in) :: x(:)  ! 
   real, intent(in) :: point  ! 
   integer, intent(inout) :: i  ! point ͤۤʤֹͤ
+  real, intent(in), optional :: undeff  ! õϰϤǤ꾮ͤõ褦Ȥ, undef ֤,  undef ͤꤹ. default Ǥ 0.
   integer :: nx, j
+  integer :: just
 
   nx=size(x)
-
-  if(x(1)>point)then
-     write(*,*) "****** ERROR ******"
-     write(*,*) "searching point was not found."
-     write(*,*) "Abort. Stop.!!!"
-     stop
+  if(present(undeff))then
+     just=int(undeff)
+  else
+     just=0
   end if
 
   do j=1,nx
-     if(x(j)<=point)then
-        i=j
-     else
+     if(x(1)>point)then
+        write(*,*) "****** WARNING ******"
+        write(*,*) "searching point was not found."
+        write(*,*) "Abort. Exit.!!!"
+        i=just
         exit
      end if
+
+     if(present(undeff))then
+        if(x(j)/=undeff)then
+           if(x(j)<=point)then
+              i=j
+           else
+              exit
+           end if
+        end if
+     else
+        if(x(j)<=point)then
+           i=j
+        else
+           exit
+        end if
+     end if
   end do
 
 end subroutine interpo_search_1d
 
 
-subroutine interpo_search_2d( x, y, pointx, pointy, i, j )
+subroutine interpo_search_2d( x, y, pointx, pointy, i, j, undeff )
   ! ǿ뤴Ȥͤ礭ʤˤΤʤ,
   ! point ֹϤ.
   implicit none
@@ -335,14 +353,22 @@ subroutine interpo_search_2d( x, y, pointx, pointy, i, j )
   real, intent(in) :: pointy  !  y
   integer, intent(inout) :: i  ! pointx ͤۤʤֹͤ
   integer, intent(inout) :: j  ! pointy ͤۤʤֹͤ
+  real, intent(in), optional :: undeff  ! õϰϤǤ꾮ͤõ褦Ȥ, undef ֤,  undef ͤꤹ. default Ǥ 0.
+  integer :: just
 
-  call interpo_search_1d( x, pointx, i )
-  call interpo_search_1d( y, pointy, j )
+  if(present(undeff))then
+     just=int(undeff)
+     call interpo_search_1d( x, pointx, i, real(just) )
+     call interpo_search_1d( y, pointy, j, real(just) )
+  else
+     call interpo_search_1d( x, pointx, i )
+     call interpo_search_1d( y, pointy, j )
+  end if
 
 end subroutine interpo_search_2d
 
 
-subroutine interpo_search_3d( x, y, z, pointx, pointy, pointz, i, j, k )
+subroutine interpo_search_3d( x, y, z, pointx, pointy, pointz, i, j, k, undeff )
   ! ǿ뤴Ȥͤ礭ʤˤΤʤ,
   ! point ֹϤ.
   implicit none
@@ -355,10 +381,19 @@ subroutine interpo_search_3d( x, y, z, pointx, pointy, pointz, i, j, k )
   integer, intent(inout) :: i  ! pointx ͤۤʤֹͤ
   integer, intent(inout) :: j  ! pointy ͤۤʤֹͤ
   integer, intent(inout) :: k  ! pointz ͤۤʤֹͤ
+  real, intent(in), optional :: undeff  ! õϰϤǤ꾮ͤõ褦Ȥ, undef ֤,  undef ͤꤹ. default Ǥ 0.
+  integer :: just
 
-  call interpo_search_1d( x, pointx, i )
-  call interpo_search_1d( y, pointy, j )
-  call interpo_search_1d( z, pointz, k )
+  if(present(undeff))then
+     just=int(undeff)
+     call interpo_search_1d( x, pointx, i, real(just) )
+     call interpo_search_1d( y, pointy, j, real(just) )
+     call interpo_search_1d( z, pointz, k, real(just) )
+  else
+     call interpo_search_1d( x, pointx, i )
+     call interpo_search_1d( y, pointy, j )
+     call interpo_search_1d( z, pointz, k )
+  end if
 
 end subroutine interpo_search_3d
 
@@ -431,13 +466,14 @@ end subroutine interpolation_3d
 
 
 
-subroutine LSM( nx, x, y, slope, intercept )  ! Ǿˡˤ뷹ҷ׻
+subroutine LSM( nx, x, y, slope, intercept, undef )  ! Ǿˡˤ뷹ҷ׻
   implicit none
   integer, intent(in) :: nx  ! ǡ
   real, intent(in) :: x(nx)  ! ǡ 1
   real, intent(in) :: y(nx)  ! ǡ 2
   real, intent(inout) :: slope  ! Ŭʷ
   real, intent(inout) :: intercept  ! Ŭ
+  real, intent(in), optional :: undef ! undef 
   real :: u(nx), v(nx)
   integer :: i, j, k
   real :: a, b, c, d
@@ -454,26 +490,35 @@ subroutine LSM( nx, x, y, slope, intercept )  ! Ǿˡˤ뷹ҷ׻
   end do
 !$omp end parallel do
 
-  call summ(nx,v,a)
-  call summ(nx,x,b)
-  call summ(nx,y,c)
-  call summ(nx,u,d)
+  call summ(nx,v,a,undef)
+  call summ(nx,x,b,undef)
+  call summ(nx,y,c,undef)
+  call summ(nx,u,d,undef)
 
   slope=(nx*a-b*c)/(nx*d-b**2)
   intercept=(c*d-a*b)/(nx*d-b**2)
 
   contains
-  subroutine summ(nx,z,add)
+  subroutine summ(nx,z,add,undeff)
     implicit none
     integer, intent(in) :: nx
     real, intent(in) :: z(nx)
     real, intent(inout) :: add
+    real, intent(in), optional :: undeff
     integer :: i
 
     add=0.0
-    do i=1,nx
-       add=add+z(i)
-    end do
+    if(present(undeff))then
+       do i=1,nx
+          if(undeff/=z(i))then
+             add=add+z(i)
+          end if
+       end do
+    else
+       do i=1,nx
+          add=add+z(i)
+       end do
+    end if
 
   end subroutine summ
 
